@@ -226,8 +226,9 @@ class ClientFactory extends Polari.ClientFactory {
     }
 });
 
-const PolariAccount = GObject.registerClass({
-    Properties: {
+const PolariAccount = GObject.registerClass(
+class PolariAccount extends Tp.Account {
+    static [GObject.properties] = {
         predefined: GObject.ParamSpec.boolean(
             'predefined', 'predefined', 'predefined',
             GObject.ParamFlags.READABLE,
@@ -244,15 +245,14 @@ const PolariAccount = GObject.registerClass({
             'settings', 'settings', 'settings',
             GObject.ParamFlags.READABLE,
             Gio.Settings.$gtype),
-    },
-}, class PolariAccount extends Tp.Account {
-    _init(params) {
-        this._visible = true;
-        this._reachable = undefined;
+    };
 
-        this._networksManager = NetworksManager.getDefault();
+    _visible = true;
+    _reachable = undefined;
+    _networksManager = NetworksManager.getDefault();
 
-        super._init(params);
+    constructor(params) {
+        super(params);
 
         this._settings = new Gio.Settings({
             schema_id: 'org.gnome.Polari.Account',
