@@ -46,23 +46,21 @@ const NICKTAG_PREFIX = 'nick';
 
 // Workaround for GtkTextView growing horizontally over time when
 // added to a GtkScrolledWindow with horizontal scrolling disabled
-const TextView = GObject.registerClass({
-    Properties: {
+const TextView = GObject.registerClass(
+class TextView extends Gtk.TextView {
+    static [GObject.properties] = {
         'indent-width-chars': GObject.ParamSpec.uint(
             'indent-width-chars', 'indent-width-chars', 'indent-width-chars',
-            GObject.ParamFlags.READWRITE,
+            GObject.ParamFlags.READWRITE | GObject.ParamFlags.CONSTRUCT,
             0, GLib.MAXUINT32, 0),
         'indext-spacing': GObject.ParamSpec.uint(
             'indent-spacing', 'indent-spacing', 'indent-spacing',
-            GObject.ParamFlags.READWRITE,
+            GObject.ParamFlags.READWRITE | GObject.ParamFlags.CONSTRUCT,
             0, GLib.MAXUINT32, 0),
-    },
-}, class TextView extends Gtk.TextView {
-    _init(params) {
-        this._indentWidthChars = 0;
-        this._indentSpacing = 0;
+    };
 
-        super._init(params);
+    constructor(params) {
+        super(params);
 
         this.buffer.connect('mark-set', this._onMarkSet.bind(this));
         this.connect('notify::root', this._onScreenChanged.bind(this));
@@ -207,34 +205,19 @@ const TextView = GObject.registerClass({
     }
 });
 
-const ButtonTag = GObject.registerClass({
-    Properties: {
+const ButtonTag = GObject.registerClass(
+class ButtonTag extends Gtk.TextTag {
+    static [GObject.properties] = {
         'hover': GObject.ParamSpec.boolean(
             'hover', 'hover', 'hover',
             GObject.ParamFlags.READWRITE,
             false),
-    },
-    Signals: {
+    };
+
+    static [GObject.signals] = {
         'clicked': { param_types: [GObject.TYPE_DOUBLE, GObject.TYPE_DOUBLE] },
         'popup-menu': { param_types: [GObject.TYPE_DOUBLE, GObject.TYPE_DOUBLE] },
-    },
-}, class ButtonTag extends Gtk.TextTag {
-    _init(params) {
-        this._hover = false;
-        super._init(params);
-    }
-
-    get hover() {
-        return this._hover;
-    }
-
-    set hover(hover) {
-        if (this._hover === hover)
-            return;
-
-        this._hover = hover;
-        this.notify('hover');
-    }
+    };
 
     clicked(...coords) {
         this.emit('clicked', ...coords);
@@ -245,8 +228,9 @@ const ButtonTag = GObject.registerClass({
     }
 });
 
-const HoverFilterTag = GObject.registerClass({
-    Properties: {
+const HoverFilterTag = GObject.registerClass(
+class HoverFilterTag extends ButtonTag {
+    static [GObject.properties] = {
         'filtered-tag': GObject.ParamSpec.object(
             'filtered-tag', 'filtered-tag', 'filtered-tag',
             GObject.ParamFlags.READWRITE | GObject.ParamFlags.CONSTRUCT_ONLY,
@@ -255,13 +239,10 @@ const HoverFilterTag = GObject.registerClass({
             'hover-opacity', 'hover-opacity', 'hover-opacity',
             GObject.ParamFlags.READWRITE,
             0.0, 1.0, 1.0),
-    },
-}, class HoverFilterTag extends ButtonTag {
-    _init(params) {
-        this._filteredTag = null;
-        this._hoverOpacity = 1.;
+    };
 
-        super._init(params);
+    constructor(params) {
+        super(params);
 
         this.connect('notify::hover', () => this._updateColor());
     }
@@ -309,18 +290,19 @@ const HoverFilterTag = GObject.registerClass({
     }
 });
 
-export default GObject.registerClass({
-    Implements: [DropTargetIface],
-    Properties: {
+export default GObject.registerClass(
+class ChatView extends Gtk.ScrolledWindow {
+    static [GObject.interfaces] = [DropTargetIface];
+    static [GObject.properties] = {
         'can-drop': GObject.ParamSpec.override('can-drop', DropTargetIface),
         'max-nick-chars': GObject.ParamSpec.uint(
             'max-nick-chars', 'max-nick-chars', 'max-nick-chars',
             GObject.ParamFlags.READABLE,
             0, GLib.MAXUINT32, 0),
-    },
-}, class ChatView extends Gtk.ScrolledWindow {
-    _init(room) {
-        super._init({ hscrollbar_policy: Gtk.PolicyType.NEVER, vexpand: true });
+    };
+
+    constructor(room) {
+        super({ hscrollbar_policy: Gtk.PolicyType.NEVER, vexpand: true });
 
         this.add_css_class('polari-chat-view');
 
