@@ -6,7 +6,6 @@ import GObject from 'gi://GObject';
 import Gtk from 'gi://Gtk';
 import Tp from 'gi://TelepathyGLib';
 
-import { MAX_NICK_CHARS } from './chatView.js';
 import { DropTargetIface, gtypeFromFormats } from './pasteManager.js';
 import IrcParser from './ircParser.js';
 import TabCompletion from './tabCompletion.js';
@@ -17,19 +16,21 @@ const MAX_LINES = 5;
 Gio._promisify(Gio._LocalFilePrototype,
     'query_info_async', 'query_info_finish');
 
-export const ChatEntry = GObject.registerClass({
-    Implements: [DropTargetIface],
-    Properties: {
+export const ChatEntry = GObject.registerClass(
+class ChatEntry extends Gtk.Entry {
+    static [GObject.interfaces] = [DropTargetIface];
+    static [GObject.properties] = {
         'can-drop': GObject.ParamSpec.override('can-drop', DropTargetIface),
-    },
-    Signals: {
+    };
+
+    static [GObject.signals] = {
         'text-pasted': { param_types: [GObject.TYPE_STRING, GObject.TYPE_INT] },
         'image-pasted': { param_types: [GdkPixbuf.Pixbuf.$gtype] },
         'file-pasted': { param_types: [Gio.File.$gtype] },
-    },
-}, class ChatEntry extends Gtk.Entry {
-    _init(params) {
-        super._init(params);
+    };
+
+    constructor(params) {
+        super(params);
 
         const delegate = this.get_delegate();
         this.addTargets(delegate);
@@ -92,26 +93,27 @@ export const ChatEntry = GObject.registerClass({
     }
 });
 
-export const NickPopover = GObject.registerClass({
-    Template: 'resource:///org/gnome/Polari/ui/nick-popover.ui',
-    InternalChildren: [
+export const NickPopover = GObject.registerClass(
+class NickPopover extends Gtk.Popover {
+    static [Gtk.template] = 'resource:///org/gnome/Polari/ui/nick-popover.ui';
+    static [Gtk.internalChildren] = [
         'nickEntry',
         'changeButton',
-    ],
-    Properties: {
+    ];
+
+    static [GObject.properties] = {
         nick: GObject.ParamSpec.string(
             'nick', 'nick', 'nick',
             GObject.ParamFlags.READWRITE,
             ''),
-    },
-    Signals: {
-        'nick-changed': {},
-    },
-}, class NickPopover extends Gtk.Popover {
-    _init() {
-        this._nick = '';
+    };
 
-        super._init();
+    static [GObject.signals] = {
+        'nick-changed': {},
+    };
+
+    constructor() {
+        super();
 
         this.set_default_widget(this._changeButton);
 
@@ -140,9 +142,10 @@ export const NickPopover = GObject.registerClass({
     }
 });
 
-export default GObject.registerClass({
-    Template: 'resource:///org/gnome/Polari/ui/entry-area.ui',
-    InternalChildren: [
+export default GObject.registerClass(
+class EntryArea extends Gtk.Stack {
+    static [Gtk.template] = 'resource:///org/gnome/Polari/ui/entry-area.ui';
+    static [Gtk.internalChildren] = [
         'chatEntry',
         'nickButton',
         'nickLabel',
@@ -152,30 +155,31 @@ export default GObject.registerClass({
         'uploadSpinner',
         'cancelButton',
         'pasteButton',
-    ],
-    Properties: {
+    ];
+
+    static [GObject.properties] = {
         'max-nick-chars': GObject.ParamSpec.uint(
             'max-nick-chars', 'max-nick-chars', 'max-nick-chars',
             GObject.ParamFlags.WRITABLE,
             0, GLib.MAXUINT32, 0),
-    },
-}, class EntryArea extends Gtk.Stack {
+    };
+
     static get _nickPopover() {
         if (!this.__nickPopover)
             this.__nickPopover = new NickPopover();
         return this.__nickPopover;
     }
 
-    _init(params) {
-        this._room = params.room;
+    _nickChangedId = 0;
+    _popoverClosedId = 0;
+
+    constructor(params) {
+        const { room } = params;
         delete params.room;
 
-        this._ircParser = new IrcParser(this._room);
-        this._maxNickChars = MAX_NICK_CHARS;
-        this._nickChangedId = 0;
-        this._popoverClosedId = 0;
+        super(params);
 
-        super._init(params);
+        this._room = room;
 
         this.connect('destroy', this._onDestroy.bind(this));
         this.connect('notify::sensitive', this._onSensitiveChanged.bind(this));
@@ -244,15 +248,6 @@ export default GObject.registerClass({
 
         this._chatEntry.connect('changed', this._onEntryChanged.bind(this));
 
-        this._chatEntry.connect('activate', () => {
-            if (this._ircParser.process(this._chatEntry.text)) {
-                this._chatEntry.text = '';
-            } else {
-                this._chatEntry.add_css_class('error');
-                this._chatEntry.grab_focus(); // select text
-            }
-        });
-
         this._cancelButton.connect('clicked', this._onCancelClicked.bind(this));
         this._pasteButton.connect('clicked', this._onPasteClicked.bind(this));
 
@@ -272,6 +267,7 @@ export default GObject.registerClass({
         if (!this._room)
             return;
 
+        this._ircParser = new IrcParser(this._chatEntry, this._room);
         this._completion = new TabCompletion(this._chatEntry);
         this._membersChangedId = this._room.connect('members-changed',
             this._updateCompletions.bind(this));
