@@ -12,18 +12,19 @@ const SetupPage = {
     OFFLINE: 2,
 };
 
-export default GObject.registerClass({
-    Template: 'resource:///org/gnome/Polari/ui/initial-setup-window.ui',
-    InternalChildren: [
+export default GObject.registerClass(
+class InitialSetupWindow extends Gtk.Window {
+    static [Gtk.template] = 'resource:///org/gnome/Polari/ui/initial-setup-window.ui';
+    static [Gtk.internalChildren] = [
         'contentStack',
         'connectionsList',
         'nextButton',
         'prevButton',
         'serverRoomList',
-    ],
-}, class InitialSetupWindow extends Gtk.Window {
-    _init(params) {
-        super._init(params);
+    ];
+
+    constructor(params) {
+        super(params);
 
         this._currentAccount = null;
 
