@@ -1,12 +1,9 @@
-export { NetworksManager };
-
 import Gio from 'gi://Gio';
 import GLib from 'gi://GLib';
 
-const ByteArray = imports.byteArray;
 const Signals = imports.signals;
 
-const NetworksManager = class {
+export default class NetworksManager {
     static getDefault() {
         if (!this._singleton)
             this._singleton = new NetworksManager();
@@ -22,9 +19,10 @@ const NetworksManager = class {
         let data;
         try {
             [, data] = file.load_contents(null);
-            this._parseNetworks(ByteArray.toString(data));
+            this._parseNetworks(new TextDecoder().decode(data));
         } catch (e) {
-            log(`Failed to load network list: ${e.message}`);
+            console.warn('Failed to load network list');
+            console.debug(e);
         }
     }
 
@@ -33,7 +31,8 @@ const NetworksManager = class {
         try {
             networks = JSON.parse(data);
         } catch (e) {
-            log(`Failed to parse network list: ${e.message}`);
+            console.warn('Failed to parse network list');
+            console.debug(e);
             return false;
         }
 
@@ -111,5 +110,5 @@ const NetworksManager = class {
         });
         return network ? network.id : null;
     }
-};
+}
 Signals.addSignalMethods(NetworksManager.prototype);
