@@ -18,18 +18,19 @@ function _onPopoverVisibleChanged(popover) {
         popover.get_parent().remove_css_class('has-open-popup');
 }
 
-const RoomRow = GObject.registerClass({
-    Template: 'resource:///org/gnome/Polari/ui/room-list-row.ui',
-    InternalChildren: [
+const RoomRow = GObject.registerClass(
+class RoomRow extends Gtk.ListBoxRow {
+    static [Gtk.template] = 'resource:///org/gnome/Polari/ui/room-list-row.ui';
+    static [Gtk.internalChildren] = [
         'box',
         'icon',
         'roomLabel',
         'counter',
         'eventStack',
-    ],
-}, class RoomRow extends Gtk.ListBoxRow {
-    _init(room) {
-        super._init({
+    ];
+
+    constructor(room) {
+        super({
             name: `RoomRow ${room.display_name}`,
         });
 
@@ -229,8 +230,8 @@ const RoomRow = GObject.registerClass({
 
 const RoomRowPopover = GObject.registerClass(
 class RoomRowPopover extends Gtk.PopoverMenu {
-    _init(row) {
-        super._init({
+    constructor(row) {
+        super({
             position: Gtk.PositionType.BOTTOM,
         });
         this.set_parent(row);
@@ -285,10 +286,11 @@ class RoomRowPopover extends Gtk.PopoverMenu {
     }
 });
 
-const RoomListHeader = GObject.registerClass({
-    CssName: 'row',
-    Template: 'resource:///org/gnome/Polari/ui/room-list-header.ui',
-    InternalChildren: [
+const RoomListHeader = GObject.registerClass(
+class RoomListHeader extends Gtk.Widget {
+    static [Gtk.cssName] = 'row';
+    static [Gtk.template] = 'resource:///org/gnome/Polari/ui/room-list-header.ui';
+    static [Gtk.internalChildren] = [
         'label',
         'iconStack',
         'popoverStatus',
@@ -300,17 +302,19 @@ const RoomListHeader = GObject.registerClass({
         'popoverRemove',
         'popoverProperties',
         'spinner',
-    ],
-    Properties: {
+    ];
+
+    static [GObject.properties] = {
         'popover': GObject.ParamSpec.object(
             'popover', 'popover', 'popover',
             GObject.ParamFlags.READWRITE,
             Gtk.Popover.$gtype),
-    },
-    Signals: {
+    };
+
+    static [GObject.signals] = {
         'activate': { flags: GObject.SignalFlags.ACTION },
-    },
-}, class RoomListHeader extends Gtk.Widget {
+    };
+
     static _classInit(klass) {
         klass = Gtk.Widget._classInit(klass);
 
@@ -320,18 +324,19 @@ const RoomListHeader = GObject.registerClass({
         return klass;
     }
 
-    _init(params) {
-        this._account = params.account;
+    constructor(params) {
+        const { account } = params;
         delete params.account;
 
-        this._app = Gio.Application.get_default();
-        this._popover = null;
-
-        super._init({
+        super({
             ...params,
-            name: `RoomListHeader ${this._account.display_name}`,
+            name: `RoomListHeader ${account.display_name}`,
         });
 
+        this._account = account;
+
+        this._app = Gio.Application.get_default();
+
         this.connect('activate',
             () => this._popover?.popup());
 
@@ -489,11 +494,10 @@ const RoomListHeader = GObject.registerClass({
         if (this._spinner.spinning)
             this._spinnerActivationTime = GLib.get_monotonic_time();
 
-        this._popoverTitle.use_markup = isError;
-        this._popoverStatus.use_markup = !isError;
-
         if (!isError) {
             this._popoverStatus.add_css_class('dim-label');
+            this._popoverStatus.add_css_class('caption');
+            this._popoverTitle.remove_css_class('heading');
 
             let params = this._account.dup_parameters_vardict().deep_unpack();
             let server = params['server'].deep_unpack();
@@ -503,11 +507,13 @@ const RoomListHeader = GObject.registerClass({
                server address, e.g. "GNOME (irc.gnome.org)" */
             let fullTitle = vprintf(_('%s (%s)'), accountName, server);
             this._popoverTitle.label = accountName === server ? accountName : fullTitle;
-            this._popoverStatus.label = `<sup>${this._getStatusLabel()}<${'/'}sup>`;
+            this._popoverStatus.label = this._getStatusLabel();
         } else {
             this._popoverStatus.remove_css_class('dim-label');
+            this._popoverStatus.remove_css_class('caption');
+            this._popoverTitle.add_css_class('heading');
 
-            this._popoverTitle.label = `<b>${_('Connection Problem')}<${'/'}b>`;
+            this._popoverTitle.label = _('Connection Problem');
             this._popoverStatus.label = this._getErrorLabel();
         }
     }
@@ -568,8 +574,8 @@ const RoomListHeader = GObject.registerClass({
 
 export default GObject.registerClass(
 class RoomList extends Gtk.ListBox {
-    _init(params) {
-        super._init(params);
+    constructor(params) {
+        super(params);
 
         this.set_header_func(this._updateHeader.bind(this));
         this.set_sort_func(this._sort.bind(this));
