@@ -1,29 +1,27 @@
+import Adw from 'gi://Adw';
 import Gio from 'gi://Gio';
 import GLib from 'gi://GLib';
 import GObject from 'gi://GObject';
 import Gtk from 'gi://Gtk';
+import Pango from 'gi://Pango';
 import Tp from 'gi://TelepathyGLib';
 
 import AccountsMonitor from './accountsMonitor.js';
 import ChatView from './chatView.js';
 import EntryArea from './entryArea.js';
-import { MessageInfoBar } from './appNotifications.js';
 import RoomManager from './roomManager.js';
 
-export default GObject.registerClass({
-    Properties: {
-        'entry-area-height': GObject.ParamSpec.uint(
-            'entry-area-height', 'entry-area-height', 'entry-area-height',
-            GObject.ParamFlags.READABLE,
-            0, GLib.MAXUINT32, 0),
+export default GObject.registerClass(
+class RoomStack extends Gtk.Stack {
+    static [GObject.properties] = {
         'view-height': GObject.ParamSpec.uint(
             'view-height', 'view-height', 'view-height',
             GObject.ParamFlags.READABLE,
             0, GLib.MAXUINT32, 0),
-    },
-}, class RoomStack extends Gtk.Stack {
-    _init(params) {
-        super._init(params);
+    };
+
+    constructor(params) {
+        super(params);
 
         this._sizeGroup = new Gtk.SizeGroup({ mode: Gtk.SizeGroupMode.VERTICAL });
         this._rooms = new Map();
@@ -38,7 +36,6 @@ export default GObject.registerClass({
 
         this.add_named(new ChatPlaceholder(this._sizeGroup), 'placeholder');
 
-        this._entryAreaHeight = 0;
         this._viewHeight = 0;
 
         this.connect('destroy', () => {
@@ -77,10 +74,6 @@ export default GObject.registerClass({
             this._sizeGroup.get_widgets().filter(w => w.get_mapped());
         const entryHeight = firstEntry
             ? firstEntry.get_allocated_height() - 1 : 0;
-        if (this._entryAreaHeight !== entryHeight) {
-            this._entryAreaHeight = entryHeight;
-            this.notify('entry-area-height');
-        }
 
         const viewHeight = this.get_allocated_height() - entryHeight;
         if (this._viewHeight !== viewHeight) {
@@ -89,11 +82,6 @@ export default GObject.registerClass({
         }
     }
 
-    // eslint-disable-next-line camelcase
-    get entry_area_height() {
-        return this._entryAreaHeight;
-    }
-
     // eslint-disable-next-line camelcase
     get view_height() {
         return this._viewHeight;
@@ -130,16 +118,66 @@ export default GObject.registerClass({
     }
 });
 
+export const MessageInfoBar = GObject.registerClass(
+class MessageInfoBar extends Gtk.InfoBar {
+    static [GObject.properties] = {
+        'title': GObject.ParamSpec.string(
+            'title', 'title', 'title',
+            GObject.ParamFlags.READWRITE | GObject.ParamFlags.CONSTRUCT,
+            ''),
+        'subtitle': GObject.ParamSpec.string(
+            'subtitle', 'subtitle', 'subtitle',
+            GObject.ParamFlags.READWRITE | GObject.ParamFlags.CONSTRUCT,
+            ''),
+    };
+
+    constructor(params) {
+        let defaultParams = {
+            show_close_button: true,
+            revealed: false,
+            valign: Gtk.Align.START,
+        };
+        super(Object.assign(defaultParams, params));
+
+        let box = new Gtk.Box({ orientation: Gtk.Orientation.VERTICAL });
+        this.add_child(box);
+
+        this._titleLabel = new Gtk.Label({
+            css_classes: ['heading'],
+            halign: Gtk.Align.START,
+            valign: Gtk.Align.CENTER,
+            wrap: true,
+        });
+        box.append(this._titleLabel);
+
+        this._subtitleLabel = new Gtk.Label({
+            halign: Gtk.Align.START,
+            valign: Gtk.Align.CENTER,
+            ellipsize: Pango.EllipsizeMode.END,
+        });
+        box.append(this._subtitleLabel);
+
+        this.bind_property('title',
+            this._titleLabel, 'label',
+            GObject.BindingFlags.SYNC_CREATE);
+        this.bind_property('subtitle',
+            this._subtitleLabel, 'label',
+            GObject.BindingFlags.SYNC_CREATE);
+
+        this.connect('response', () => (this.revealed = false));
+    }
+});
+
 const SavePasswordConfirmationBar = GObject.registerClass(
 class SavePasswordConfirmationBar extends MessageInfoBar {
-    _init(room) {
-        this._room = room;
-
+    constructor(room) {
         let title = _('Should the password be saved?');
         let subtitle = vprintf(
             _('Identification will happen automatically the next time you connect to %s'),
-            this._room.account.display_name);
-        super._init({ title, subtitle });
+            room.account.display_name);
+        super({ title, subtitle });
+
+        this._room = room;
 
         this.connect('destroy', this._onDestroy.bind(this));
 
@@ -171,10 +209,10 @@ class SavePasswordConfirmationBar extends MessageInfoBar {
 
 const ChannelErrorBar = GObject.registerClass(
 class ChannelErrorBar extends MessageInfoBar {
-    _init(room) {
-        this._room = room;
+    constructor(room) {
+        super({ title: _('Failed to join the room') });
 
-        super._init({ title: _('Failed to join the room') });
+        this._room = room;
 
         this.add_button(_('_Retry'), Gtk.ResponseType.ACCEPT).set({
             action_name: 'app.reconnect-room',
@@ -225,55 +263,29 @@ class ChannelErrorBar extends MessageInfoBar {
 
 const ChatPlaceholder = GObject.registerClass(
 class ChatPlaceholder extends Gtk.Overlay {
-    _init(sizeGroup) {
-        this._accountsMonitor = AccountsMonitor.getDefault();
+    _accountsMonitor = AccountsMonitor.getDefault();
 
-        let image = new Gtk.Image({
+    constructor(sizeGroup) {
+        super();
+
+        const statusPage = new Adw.StatusPage({
             icon_name: 'org.gnome.Polari-symbolic',
-            pixel_size: 96, halign: Gtk.Align.END,
-            margin_end: 14,
-        });
-
-        let title = new Gtk.Label({
-            use_markup: true,
-            halign: Gtk.Align.START,
-            margin_start: 14,
-        });
-        title.label = `<span letter_spacing="4500">${_('Polari')}<${'/'}span>`;
-        title.add_css_class('polari-background-title');
-
-        let description = new Gtk.Label({
-            label: _('Join a room using the + button.'),
-            halign: Gtk.Align.CENTER, wrap: true,
-            margin_top: 24, use_markup: true,
-        });
-        description.add_css_class('polari-background-description');
-
-        let inputPlaceholder = new Gtk.Box({ valign: Gtk.Align.END });
-        sizeGroup.add_widget(inputPlaceholder);
-
-        super._init();
-        let grid = new Gtk.Grid({
-            column_homogeneous: true,
-            can_focus: false,
-            column_spacing: 18,
-            hexpand: true,
+            title: _('Polari'),
+            description: _('Join a room using the + button.'),
             vexpand: true,
-            valign: Gtk.Align.CENTER,
         });
-        grid.add_css_class('polari-background');
-        grid.attach(image, 0, 0, 1, 1);
-        grid.attach(title, 1, 0, 1, 1);
-        grid.attach(description, 0, 1, 2, 1);
-        this.set_child(grid);
+        this.set_child(statusPage);
+
+        const inputPlaceholder = new Gtk.Box({ valign: Gtk.Align.END });
+        sizeGroup.add_widget(inputPlaceholder);
         this.add_overlay(inputPlaceholder);
     }
 });
 
 const RoomView = GObject.registerClass(
 class RoomView extends Gtk.Overlay {
-    _init(room, sizeGroup) {
-        super._init({ name: `RoomView ${room.display_name}` });
+    constructor(room, sizeGroup) {
+        super({ name: `RoomView ${room.display_name}` });
 
         let box = new Gtk.Box({ orientation: Gtk.Orientation.VERTICAL });
         this.set_child(box);
