@@ -1,8 +1,3 @@
-export {
-    ServerRoomManager,
-    ServerRoomList
-};
-
 import Gdk from 'gi://Gdk';
 import Gio from 'gi://Gio';
 import GLib from 'gi://GLib';
@@ -12,8 +7,8 @@ import Tp from 'gi://TelepathyGLib';
 
 const Signals = imports.signals;
 
-import { AccountsMonitor } from './accountsMonitor.js';
-import { RoomManager } from './roomManager.js';
+import AccountsMonitor from './accountsMonitor.js';
+import RoomManager from './roomManager.js';
 import * as Utils from './utils.js';
 
 Gio._promisify(Tp.RoomList.prototype, 'init_async', 'init_finish');
@@ -21,7 +16,7 @@ Gio._promisify(Tp.RoomList.prototype, 'init_async', 'init_finish');
 const MS_PER_IDLE = 10; // max time spend in idle
 const MS_PER_FILTER_IDLE = 5; // max time spend in idle while filtering
 
-const ServerRoomManager = class {
+export default class ServerRoomManager {
     static getDefault() {
         if (!this._singleton)
             this._singleton = new ServerRoomManager();
@@ -99,7 +94,7 @@ const ServerRoomManager = class {
     _onListingChanged(list) {
         this.emit('loading-changed', list.account);
     }
-};
+}
 Signals.addSignalMethods(ServerRoomManager.prototype);
 
 
@@ -114,28 +109,30 @@ function _strBaseEqual(str1, str2) {
     return str1.localeCompare(str2, {}, { sensitivity: 'base' }) === 0;
 }
 
-const ServerRoomList = GObject.registerClass({
-    Template: 'resource:///org/gnome/Polari/ui/server-room-list.ui',
-    InternalChildren: [
+export const ServerRoomList = GObject.registerClass(
+class ServerRoomList extends Gtk.Box {
+    static [Gtk.template] = 'resource:///org/gnome/Polari/ui/server-room-list.ui';
+    static [Gtk.internalChildren] = [
         'filterEntry',
         'list',
         'spinner',
         'store',
         'toggleRenderer',
-    ],
-    Properties: {
+    ];
+
+    static [GObject.properties] = {
         'can-join': GObject.ParamSpec.boolean(
             'can-join', 'can-join', 'can-join',
             GObject.ParamFlags.READABLE,
             false),
-    },
-}, class ServerRoomList extends Gtk.Box {
-    _init(params) {
-        this._account = null;
-        this._pendingInfos = [];
-        this._filterTerms = [];
+    };
 
-        super._init(params);
+    _account = null;
+    _pendingInfos = [];
+    _filterTerms = [];
+
+    constructor(params) {
+        super(params);
 
         this._list.model.set_visible_func((model, iter) => {
             let name = model.get_value(iter, RoomListColumn.NAME);
@@ -163,10 +160,10 @@ const ServerRoomList = GObject.registerClass({
             this._updateSelection();
         });
         this._filterEntry.connect('stop-search', () => {
-            if (this._filterEntry.get_text_length() > 0)
+            if (this._filterEntry.get_text().length > 0)
                 this._filterEntry.set_text('');
-            else if (this.get_toplevel() instanceof Gtk.Dialog)
-                this.get_toplevel().response(Gtk.ResponseType.CANCEL);
+            else if (this.get_root() instanceof Gtk.Dialog)
+                this.get_root().response(Gtk.ResponseType.CANCEL);
         });
         this._filterEntry.connect('activate', () => {
             if (this._filterEntry.text.trim().length === 0)
@@ -343,7 +340,7 @@ const ServerRoomList = GObject.registerClass({
                 let count = `${roomInfo.get_members_count(null)}`;
 
                 let { CHECKED, NAME, COUNT, SENSITIVE } = RoomListColumn;
-                let iter = store.insert_with_valuesv(-1,
+                let iter = store.insert_with_values(-1,
                     [CHECKED, NAME, COUNT, SENSITIVE],
                     [checked, name, count, sensitive]);
                 store.move_before(iter, this._customRoomItem);
@@ -364,7 +361,7 @@ const ServerRoomList = GObject.registerClass({
     _checkSpinner() {
         let loading = this._pendingInfos.length ||
                       this._account && this._manager.isLoading(this._account);
-        this._spinner.active = loading;
+        this._spinner.spinning = loading;
     }
 
     _toggleChecked(path) {
