@@ -13,8 +13,8 @@ const MAX_USERS_WIDTH_CHARS = 17;
 
 export const UserListPopover = GObject.registerClass(
 class UserListPopover extends Gtk.Popover {
-    _init(params) {
-        super._init(params);
+    constructor(params) {
+        super(params);
 
         this._createWidget();
 
@@ -109,9 +109,10 @@ class UserListPopover extends Gtk.Popover {
     }
 });
 
-export const UserDetails = GObject.registerClass({
-    Template: 'resource:///org/gnome/Polari/ui/user-details.ui',
-    InternalChildren: [
+export const UserDetails = GObject.registerClass(
+class UserDetails extends Gtk.Box {
+    static [Gtk.template] = 'resource:///org/gnome/Polari/ui/user-details.ui';
+    static [Gtk.internalChildren] = [
         'spinnerBox',
         'spinner',
         'detailsGrid',
@@ -119,8 +120,9 @@ export const UserDetails = GObject.registerClass({
         'lastLabel',
         'notificationLabel',
         'messageButton',
-    ],
-    Properties: {
+    ];
+
+    static [GObject.properties] = {
         'expanded': GObject.ParamSpec.boolean(
             'expanded', 'expanded', 'expanded',
             GObject.ParamFlags.READWRITE,
@@ -129,18 +131,16 @@ export const UserDetails = GObject.registerClass({
             'notifications-enabled', 'notifications-enabled', 'notifications-enabled',
             GObject.ParamFlags.READWRITE,
             false),
-    },
-}, class UserDetails extends Gtk.Box {
-    _init(params = {}) {
+    };
+
+    _initialDetailsLoaded = false;
+    _user = null;
+
+    constructor(params = {}) {
         let { user } = params;
         delete params.user;
 
-        this._expanded = false;
-        this._initialDetailsLoaded = false;
-        this._notificationsEnabled = false;
-        this._user = null;
-
-        super._init(params);
+        super(params);
 
         this.user = user;
 
@@ -149,24 +149,19 @@ export const UserDetails = GObject.registerClass({
 
         this._updateButtonVisibility();
         this._detailsGrid.hide();
-        this._notificationLabel.opacity = this.notifications_enabled ? 1. : 0.;
-    }
 
-    // eslint-disable-next-line camelcase
-    get notifications_enabled() {
-        return this._notificationsEnabled;
-    }
+        this.bind_property_full('notifications-enabled',
+            this._notificationLabel, 'opacity',
+            GObject.BindingFlags.SYNC_CREATE,
+            (p, source) => [true, source ? 1. : 0.],
+            null);
 
-    // eslint-disable-next-line camelcase
-    set notifications_enabled(value) {
-        if (this._notificationsEnabled === value)
-            return;
-
-        this._notificationsEnabled = value;
-
-        this.notify('notifications-enabled');
-
-        this._notificationLabel.opacity = value ? 1. : 0.;
+        this.connect('notify::expanded', () => {
+            if (this.expanded)
+                this._expand();
+            else
+                this._unexpand();
+        });
     }
 
     set user(user) {
@@ -203,24 +198,6 @@ export const UserDetails = GObject.registerClass({
         this._updateButtonVisibility();
     }
 
-    get expanded() {
-        return this._expanded;
-    }
-
-    set expanded(v) {
-        if (v === this._expanded)
-            return;
-
-        this._expanded = v;
-
-        if (this._expanded)
-            this._expand();
-        else
-            this._unexpand();
-
-        this.notify('expanded');
-    }
-
     _expand() {
         this._detailsGrid.visible = this._initialDetailsLoaded;
         this._spinnerBox.visible = !this._initialDetailsLoaded;
@@ -309,26 +286,28 @@ export const UserDetails = GObject.registerClass({
     }
 });
 
-export const UserPopover = GObject.registerClass({
-    Template: 'resource:///org/gnome/Polari/ui/user-popover.ui',
-    InternalChildren: [
+export const UserPopover = GObject.registerClass(
+class UserPopover extends Gtk.Popover {
+    static [Gtk.template] = 'resource:///org/gnome/Polari/ui/user-popover.ui';
+    static [Gtk.internalChildren] = [
         'nickLabel',
         'statusLabel',
         'notifyButton',
         'userDetails',
-    ],
-}, class UserPopover extends Gtk.Popover {
-    _init(params) {
-        this._room = params.room;
-        delete params.room;
+    ];
 
-        this._userTracker = params.userTracker;
+    _nickname = null;
+    _basenick = null;
+
+    constructor(params) {
+        const { room, userTracker } = params;
+        delete params.room;
         delete params.userTracker;
 
-        this._nickname = null;
-        this._basenick = null;
+        super(params);
 
-        super._init(params);
+        this._room = room;
+        this._userTracker = userTracker;
 
         this._app = Gio.Application.get_default();
 
@@ -422,10 +401,10 @@ export const UserPopover = GObject.registerClass({
 
 const UserListRow = GObject.registerClass(
 class UserListRow extends Gtk.ListBoxRow {
-    _init(user) {
-        this._user = user;
+    constructor(user) {
+        super({ name: `UserListRow ${user.alias}` });
 
-        super._init({ name: `UserListRow ${user.alias}` });
+        this._user = user;
 
         this._createWidget();
 
